pub struct TextSnippetSourceConfig {
pub name: String,
pub keyword: String,
pub icon: Option<String>,
pub snippets: Option<Vec<TextSnippet>>,
pub file: Option<String>,
pub command: Option<String>,
pub directory: Option<String>,
pub args: Vec<String>,
pub action: Option<String>,
pub secondary_action: Option<String>,
}Expand description
Configuration for a text snippet source
Fields
name: Stringkeyword: Stringicon: Option<String>snippets: Option<Vec<TextSnippet>>file: Option<String>command: Option<String>directory: Option<String>args: Vec<String>action: Option<String>secondary_action: Option<String>Trait Implementations
Sourceimpl Clone for TextSnippetSourceConfig
impl Clone for TextSnippetSourceConfig
Sourcefn clone(&self) -> TextSnippetSourceConfig
fn clone(&self) -> TextSnippetSourceConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TextSnippetSourceConfig
impl Debug for TextSnippetSourceConfig
Sourceimpl<'de> Deserialize<'de> for TextSnippetSourceConfig
impl<'de> Deserialize<'de> for TextSnippetSourceConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TextSnippetSourceConfig
impl JsonSchema for TextSnippetSourceConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TextSnippetSourceConfig
impl RefUnwindSafe for TextSnippetSourceConfig
impl Send for TextSnippetSourceConfig
impl Sync for TextSnippetSourceConfig
impl Unpin for TextSnippetSourceConfig
impl UnsafeUnpin for TextSnippetSourceConfig
impl UnwindSafe for TextSnippetSourceConfig